<?php
/*
Plugin Name: WP Watch Movies (shared on scriptcamp.ir)
Description: WP Watch Movies plugin let's you run your own Movies & TV Shows listing website with embed/external links to watch.
Version: 1.0
Author: Crivion
Author URI: http://crivion.com
*/


/**
 * Install/Remove Database Table
 */
require_once 'includes/wpwm-install-db.php';

register_activation_hook( __FILE__, 'wpwm_install_db' );
register_deactivation_hook( __FILE__, 'wpwm_remove_db' );

/* Define pagination stuff */
define( 'WPWM_ITEMS_PER_PAGE', get_option('wpwm_movies_per_page', 10) );
define( 'WPWM_ITEMS_PER_ROW', get_option('wpwm_movies_per_row', 5) );
define( 'WPWPM_HOMEPAGE_PER_PAGE', get_option('wpwm_homepage_items', 5));

/* Load Plugin JS/CSS */
function wpwm_CSS() {

	wp_register_style( 'wpwm_rateIt_CSS', plugins_url( 'rate-it/rateit.css', __FILE__ ) );
	wp_enqueue_style( 'wpwm_rateIt_CSS' );

	wp_register_style( 'wpwm_plugin_CSS', plugins_url( 'css/wpwm-css.css', __FILE__ ) );
	wp_enqueue_style( 'wpwm_plugin_CSS' );

}

add_action( 'wp_head', 'wpwmCallbackToAddMeta' );
function wpwmCallbacktoAddMeta() {
	echo "<script type='text/javascript'>";
	echo 'var blog_url = "' . get_bloginfo( 'url' ) . '";';
	echo '</script>';
}

function wpwm_JS() {

	wp_enqueue_script( 'jquery' );

	wp_register_script( 'wpwm_rateIt_JS', plugins_url( $path ='rate-it/jquery.rateit.min.js', __FILE__ ) );
	wp_enqueue_script( 'wpwm_rateIt_JS' );

	wp_register_script( 'wpwm_jForm', plugins_url( $path ='js/jquery.form.min.js', __FILE__ ) );
	wp_enqueue_script( 'wpwm_jForm' );

	wp_register_script( 'wpwm_blockUI', 'http://malsup.github.io/jquery.blockUI.js' );
	wp_enqueue_script( 'wpwm_blockUI' );

	wp_register_script( 'wpwm_tabify', plugins_url( $path = 'js/jquery.tabify.js', __FILE__ ) );
	wp_enqueue_script( 'wpwm_tabify' );

	wp_register_script( 'wpwm_JS', plugins_url( $path = 'js/wpwm-ajax.js', __FILE__ ) );
	wp_enqueue_script( 'wpwm_JS' );


}

add_action( 'wp_enqueue_scripts', 'wpwm_CSS', 99 );
add_action( 'wp_enqueue_scripts', 'wpwm_JS' );

/**
 * Add custom post type movies
 */
require_once 'includes/wpwm-custom-post-types.php';

/**
 * Add Metaboxes
 */
require_once 'includes/wpwm-meta-boxes.php';

/**
 * Add WP-Admin Pages
 */
require_once 'includes/wpwm-admin-pages.php';

/*
 * Custom template for single movie/tv show page
 * Includes archive/category/genre/type template as well
 */
require_once 'includes/wpwm-template.php';
require_once 'includes/wpwm-main-page.php';

add_shortcode( 'wpwm_movies', 'wpwm_main_page' );


/* 
 * Add tab groups - main plugin page
 */
require_once 'includes/wpwm-shortcode.php';

/* AJAX Filtering Page */
require_once 'includes/wpwm-ajax.php';
add_shortcode( 'wpwm_ajax', 'wpwm_ajax' );

//star rating
add_action( 'wp_ajax_wpwm_rate', 'wpwm_rate' );
add_action( 'wp_ajax_nopriv_wpwm_rate', 'wpwm_rate' );

//link rating
add_action( 'wp_ajax_wpwm_link_rate', 'wpwm_link_rate' );
add_action( 'wp_ajax_nopriv_wpwm_link_rate', 'wpwm_link_rate' );

/*Redirect page*/
require_once 'includes/wpwm-redirect.php';

/*Include widgets*/
require_once 'includes/wpwm-widget.php';

/*Add All "KINDS" + "GENRES" Pages*/
require_once 'includes/wpwm-kinds.php';

function wpwm_add_query_vars() {
    global $wp;

    $wp->add_query_var('kind');
    $wp->add_query_var('genre');
}

add_filter('init', 'wpwm_add_query_vars');

function wpwm_rewrite_rules() {
    add_rewrite_rule('watch-online/(.*)$', 'index.php?pagename=watch-online&kind=$matches[1]', 'top');
    add_rewrite_rule('watch-genre/(.*)$', 'index.php?pagename=watch-online&genre=$matches[1]', 'top');
}

add_action('init','wpwm_rewrite_rules');